/*******************************************************************************
* File Name: comp.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_comp_H) /* Pins comp_H */
#define CY_PINS_comp_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "comp_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    comp_Write(uint8 value) ;
void    comp_SetDriveMode(uint8 mode) ;
uint8   comp_ReadDataReg(void) ;
uint8   comp_Read(void) ;
void    comp_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   comp_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the comp_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define comp_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define comp_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define comp_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define comp_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define comp_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define comp_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define comp_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define comp_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define comp_MASK               comp__MASK
#define comp_SHIFT              comp__SHIFT
#define comp_WIDTH              1u

/* Interrupt constants */
#if defined(comp__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in comp_SetInterruptMode() function.
     *  @{
     */
        #define comp_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define comp_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define comp_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define comp_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define comp_INTR_MASK      (0x01u)
#endif /* (comp__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define comp_PS                     (* (reg8 *) comp__PS)
/* Data Register */
#define comp_DR                     (* (reg8 *) comp__DR)
/* Port Number */
#define comp_PRT_NUM                (* (reg8 *) comp__PRT) 
/* Connect to Analog Globals */                                                  
#define comp_AG                     (* (reg8 *) comp__AG)                       
/* Analog MUX bux enable */
#define comp_AMUX                   (* (reg8 *) comp__AMUX) 
/* Bidirectional Enable */                                                        
#define comp_BIE                    (* (reg8 *) comp__BIE)
/* Bit-mask for Aliased Register Access */
#define comp_BIT_MASK               (* (reg8 *) comp__BIT_MASK)
/* Bypass Enable */
#define comp_BYP                    (* (reg8 *) comp__BYP)
/* Port wide control signals */                                                   
#define comp_CTL                    (* (reg8 *) comp__CTL)
/* Drive Modes */
#define comp_DM0                    (* (reg8 *) comp__DM0) 
#define comp_DM1                    (* (reg8 *) comp__DM1)
#define comp_DM2                    (* (reg8 *) comp__DM2) 
/* Input Buffer Disable Override */
#define comp_INP_DIS                (* (reg8 *) comp__INP_DIS)
/* LCD Common or Segment Drive */
#define comp_LCD_COM_SEG            (* (reg8 *) comp__LCD_COM_SEG)
/* Enable Segment LCD */
#define comp_LCD_EN                 (* (reg8 *) comp__LCD_EN)
/* Slew Rate Control */
#define comp_SLW                    (* (reg8 *) comp__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define comp_PRTDSI__CAPS_SEL       (* (reg8 *) comp__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define comp_PRTDSI__DBL_SYNC_IN    (* (reg8 *) comp__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define comp_PRTDSI__OE_SEL0        (* (reg8 *) comp__PRTDSI__OE_SEL0) 
#define comp_PRTDSI__OE_SEL1        (* (reg8 *) comp__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define comp_PRTDSI__OUT_SEL0       (* (reg8 *) comp__PRTDSI__OUT_SEL0) 
#define comp_PRTDSI__OUT_SEL1       (* (reg8 *) comp__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define comp_PRTDSI__SYNC_OUT       (* (reg8 *) comp__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(comp__SIO_CFG)
    #define comp_SIO_HYST_EN        (* (reg8 *) comp__SIO_HYST_EN)
    #define comp_SIO_REG_HIFREQ     (* (reg8 *) comp__SIO_REG_HIFREQ)
    #define comp_SIO_CFG            (* (reg8 *) comp__SIO_CFG)
    #define comp_SIO_DIFF           (* (reg8 *) comp__SIO_DIFF)
#endif /* (comp__SIO_CFG) */

/* Interrupt Registers */
#if defined(comp__INTSTAT)
    #define comp_INTSTAT             (* (reg8 *) comp__INTSTAT)
    #define comp_SNAP                (* (reg8 *) comp__SNAP)
    
	#define comp_0_INTTYPE_REG 		(* (reg8 *) comp__0__INTTYPE)
#endif /* (comp__INTSTAT) */

#endif /* End Pins comp_H */


/* [] END OF FILE */
