/*******************************************************************************
* File Name: CodeQD.h  
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the Quadrature
*  Decoder component.
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_QUADRATURE_DECODER_CodeQD_H)
#define CY_QUADRATURE_DECODER_CodeQD_H

#include "cyfitter.h"
#include "CyLib.h"
#include "cytypes.h"

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component QuadDec_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#define CodeQD_COUNTER_SIZE               (8u)
#define CodeQD_COUNTER_SIZE_8_BIT         (8u)
#define CodeQD_COUNTER_SIZE_16_BIT        (16u)
#define CodeQD_COUNTER_SIZE_32_BIT        (32u)

#if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT)
    #include "CodeQD_Cnt8.h"
#else 
    /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_16_BIT) || 
    *  (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT) 
    */
    #include "CodeQD_Cnt16.h"
#endif /* CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT */

extern uint8 CodeQD_initVar;


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define CodeQD_COUNTER_RESOLUTION         (4u)


/***************************************
*       Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
} CodeQD_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  CodeQD_Init(void) ;
void  CodeQD_Start(void) ;
void  CodeQD_Stop(void) ;
void  CodeQD_Enable(void) ;
uint8 CodeQD_GetEvents(void) ;
void  CodeQD_SetInterruptMask(uint8 mask) ;
uint8 CodeQD_GetInterruptMask(void) ;
int8 CodeQD_GetCounter(void) ;
void  CodeQD_SetCounter(int8 value)
;
void  CodeQD_Sleep(void) ;
void  CodeQD_Wakeup(void) ;
void  CodeQD_SaveConfig(void) ;
void  CodeQD_RestoreConfig(void) ;

#if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT)
    CY_ISR_PROTO(CodeQD_ISR);
#endif /* CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT */


/***************************************
*           API Constants
***************************************/

#if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT)
    #define CodeQD_ISR_NUMBER             ((uint8) CodeQD_isr__INTC_NUMBER)
    #define CodeQD_ISR_PRIORITY           ((uint8) CodeQD_isr__INTC_PRIOR_NUM)
#endif /* CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT */


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define CodeQD_GLITCH_FILTERING           (0u)
#define CodeQD_INDEX_INPUT                (0u)


/***************************************
*    Initial Parameter Constants
***************************************/

#if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT)
    #define CodeQD_COUNTER_INIT_VALUE    (0x80u)
#else 
    /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_16_BIT) ||
    *  (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT)
    */
    #define CodeQD_COUNTER_INIT_VALUE    (0x8000u)
    #define CodeQD_COUNTER_MAX_VALUE     (0x7FFFu)
#endif /* CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT */


/***************************************
*             Registers
***************************************/

#define CodeQD_STATUS_REG                 (* (reg8 *) CodeQD_bQuadDec_Stsreg__STATUS_REG)
#define CodeQD_STATUS_PTR                 (  (reg8 *) CodeQD_bQuadDec_Stsreg__STATUS_REG)
#define CodeQD_STATUS_MASK                (* (reg8 *) CodeQD_bQuadDec_Stsreg__MASK_REG)
#define CodeQD_STATUS_MASK_PTR            (  (reg8 *) CodeQD_bQuadDec_Stsreg__MASK_REG)
#define CodeQD_SR_AUX_CONTROL             (* (reg8 *) CodeQD_bQuadDec_Stsreg__STATUS_AUX_CTL_REG)
#define CodeQD_SR_AUX_CONTROL_PTR         (  (reg8 *) CodeQD_bQuadDec_Stsreg__STATUS_AUX_CTL_REG)


/***************************************
*        Register Constants
***************************************/

#define CodeQD_COUNTER_OVERFLOW_SHIFT     (0x00u)
#define CodeQD_COUNTER_UNDERFLOW_SHIFT    (0x01u)
#define CodeQD_COUNTER_RESET_SHIFT        (0x02u)
#define CodeQD_INVALID_IN_SHIFT           (0x03u)
#define CodeQD_COUNTER_OVERFLOW           ((uint8) (0x01u << CodeQD_COUNTER_OVERFLOW_SHIFT))
#define CodeQD_COUNTER_UNDERFLOW          ((uint8) (0x01u << CodeQD_COUNTER_UNDERFLOW_SHIFT))
#define CodeQD_COUNTER_RESET              ((uint8) (0x01u << CodeQD_COUNTER_RESET_SHIFT))
#define CodeQD_INVALID_IN                 ((uint8) (0x01u << CodeQD_INVALID_IN_SHIFT))

#define CodeQD_INTERRUPTS_ENABLE_SHIFT    (0x04u)
#define CodeQD_INTERRUPTS_ENABLE          ((uint8)(0x01u << CodeQD_INTERRUPTS_ENABLE_SHIFT))
#define CodeQD_INIT_INT_MASK              (0x0Fu)


/******************************************************************************************
* Following code are OBSOLETE and must not be used starting from Quadrature Decoder 2.20
******************************************************************************************/
#define CodeQD_DISABLE                    (0x00u)


#endif /* CY_QUADRATURE_DECODER_CodeQD_H */


/* [] END OF FILE */
