/*******************************************************************************
* File Name: CodeQD_PM.c
* Version 3.0
*
* Description:
*  This file contains the setup, control and status commands to support 
*  component operations in low power mode.  
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CodeQD.h"

static CodeQD_BACKUP_STRUCT CodeQD_backup = {0u};


/*******************************************************************************
* Function Name: CodeQD_SaveConfig
********************************************************************************
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CodeQD_SaveConfig(void) 
{
    #if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT)
        CodeQD_Cnt8_SaveConfig();
    #else 
        /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_16_BIT) || 
         * (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT)
         */
        CodeQD_Cnt16_SaveConfig();
    #endif /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: CodeQD_RestoreConfig
********************************************************************************
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CodeQD_RestoreConfig(void) 
{
    #if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT)
        CodeQD_Cnt8_RestoreConfig();
    #else 
        /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_16_BIT) || 
         * (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT) 
         */
        CodeQD_Cnt16_RestoreConfig();
    #endif /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: CodeQD_Sleep
********************************************************************************
* 
* Summary:
*  Prepare Quadrature Decoder Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CodeQD_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void CodeQD_Sleep(void) 
{
    if (0u != (CodeQD_SR_AUX_CONTROL & CodeQD_INTERRUPTS_ENABLE))
    {
        CodeQD_backup.enableState = 1u;
    }
    else /* The Quadrature Decoder Component is disabled */
    {
        CodeQD_backup.enableState = 0u;
    }

    CodeQD_Stop();
    CodeQD_SaveConfig();
}


/*******************************************************************************
* Function Name: CodeQD_Wakeup
********************************************************************************
*
* Summary:
*  Prepare Quadrature Decoder Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CodeQD_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void CodeQD_Wakeup(void) 
{
    CodeQD_RestoreConfig();

    if (CodeQD_backup.enableState != 0u)
    {
        #if (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT)
            CodeQD_Cnt8_Enable();
        #else 
            /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_16_BIT) || 
            *  (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_32_BIT) 
            */
            CodeQD_Cnt16_Enable();
        #endif /* (CodeQD_COUNTER_SIZE == CodeQD_COUNTER_SIZE_8_BIT) */

        /* Enable component's operation */
        CodeQD_Enable();
    } /* Do nothing if component's block was disabled before */
}


/* [] END OF FILE */

