/*******************************************************************************
* File Name: EEPROM_FF_Reset_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "EEPROM_FF_Reset.h"

/* Check for removal by optimization */
#if !defined(EEPROM_FF_Reset_Sync_ctrl_reg__REMOVED)

static EEPROM_FF_Reset_BACKUP_STRUCT  EEPROM_FF_Reset_backup = {0u};

    
/*******************************************************************************
* Function Name: EEPROM_FF_Reset_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EEPROM_FF_Reset_SaveConfig(void) 
{
    EEPROM_FF_Reset_backup.controlState = EEPROM_FF_Reset_Control;
}


/*******************************************************************************
* Function Name: EEPROM_FF_Reset_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void EEPROM_FF_Reset_RestoreConfig(void) 
{
     EEPROM_FF_Reset_Control = EEPROM_FF_Reset_backup.controlState;
}


/*******************************************************************************
* Function Name: EEPROM_FF_Reset_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EEPROM_FF_Reset_Sleep(void) 
{
    EEPROM_FF_Reset_SaveConfig();
}


/*******************************************************************************
* Function Name: EEPROM_FF_Reset_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EEPROM_FF_Reset_Wakeup(void)  
{
    EEPROM_FF_Reset_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
