/*******************************************************************************
* File Name: Save_EEPROM.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Save_EEPROM.h"

#if !defined(Save_EEPROM_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: Save_EEPROM_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 Save_EEPROM_Read(void) 
{ 
    return Save_EEPROM_Status;
}


/*******************************************************************************
* Function Name: Save_EEPROM_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Save_EEPROM_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Save_EEPROM_Status_Aux_Ctrl |= Save_EEPROM_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Save_EEPROM_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Save_EEPROM_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Save_EEPROM_Status_Aux_Ctrl &= (uint8)(~Save_EEPROM_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Save_EEPROM_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void Save_EEPROM_WriteMask(uint8 mask) 
{
    #if(Save_EEPROM_INPUTS < 8u)
    	mask &= ((uint8)(1u << Save_EEPROM_INPUTS) - 1u);
	#endif /* End Save_EEPROM_INPUTS < 8u */
    Save_EEPROM_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: Save_EEPROM_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 Save_EEPROM_ReadMask(void) 
{
    return Save_EEPROM_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
