/*******************************************************************************
* File Name: Timers_RST_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Timers_RST.h"

/* Check for removal by optimization */
#if !defined(Timers_RST_Sync_ctrl_reg__REMOVED)

static Timers_RST_BACKUP_STRUCT  Timers_RST_backup = {0u};

    
/*******************************************************************************
* Function Name: Timers_RST_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timers_RST_SaveConfig(void) 
{
    Timers_RST_backup.controlState = Timers_RST_Control;
}


/*******************************************************************************
* Function Name: Timers_RST_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Timers_RST_RestoreConfig(void) 
{
     Timers_RST_Control = Timers_RST_backup.controlState;
}


/*******************************************************************************
* Function Name: Timers_RST_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timers_RST_Sleep(void) 
{
    Timers_RST_SaveConfig();
}


/*******************************************************************************
* Function Name: Timers_RST_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timers_RST_Wakeup(void)  
{
    Timers_RST_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
