/*******************************************************************************
* File Name: TonePWM.h
* Version 3.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_TonePWM_H)
#define CY_PWM_TonePWM_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 TonePWM_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define TonePWM_Resolution                     (8u)
#define TonePWM_UsingFixedFunction             (0u)
#define TonePWM_DeadBandMode                   (0u)
#define TonePWM_KillModeMinTime                (0u)
#define TonePWM_KillMode                       (0u)
#define TonePWM_PWMMode                        (0u)
#define TonePWM_PWMModeIsCenterAligned         (0u)
#define TonePWM_DeadBandUsed                   (0u)
#define TonePWM_DeadBand2_4                    (0u)

#if !defined(TonePWM_PWMUDB_genblk8_stsreg__REMOVED)
    #define TonePWM_UseStatus                  (0u)
#else
    #define TonePWM_UseStatus                  (0u)
#endif /* !defined(TonePWM_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(TonePWM_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define TonePWM_UseControl                 (1u)
#else
    #define TonePWM_UseControl                 (0u)
#endif /* !defined(TonePWM_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define TonePWM_UseOneCompareMode              (1u)
#define TonePWM_MinimumKillTime                (1u)
#define TonePWM_EnableMode                     (0u)

#define TonePWM_CompareMode1SW                 (0u)
#define TonePWM_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define TonePWM__B_PWM__DISABLED 0
#define TonePWM__B_PWM__ASYNCHRONOUS 1
#define TonePWM__B_PWM__SINGLECYCLE 2
#define TonePWM__B_PWM__LATCHED 3
#define TonePWM__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define TonePWM__B_PWM__DBMDISABLED 0
#define TonePWM__B_PWM__DBM_2_4_CLOCKS 1
#define TonePWM__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define TonePWM__B_PWM__ONE_OUTPUT 0
#define TonePWM__B_PWM__TWO_OUTPUTS 1
#define TonePWM__B_PWM__DUAL_EDGE 2
#define TonePWM__B_PWM__CENTER_ALIGN 3
#define TonePWM__B_PWM__DITHER 5
#define TonePWM__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define TonePWM__B_PWM__LESS_THAN 1
#define TonePWM__B_PWM__LESS_THAN_OR_EQUAL 2
#define TonePWM__B_PWM__GREATER_THAN 3
#define TonePWM__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define TonePWM__B_PWM__EQUAL 0
#define TonePWM__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!TonePWM_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!TonePWM_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!TonePWM_PWMModeIsCenterAligned) */
        #if (TonePWM_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (TonePWM_UseStatus) */

        /* Backup for Deadband parameters */
        #if(TonePWM_DeadBandMode == TonePWM__B_PWM__DBM_256_CLOCKS || \
            TonePWM_DeadBandMode == TonePWM__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(TonePWM_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (TonePWM_KillModeMinTime) */

        /* Backup control register */
        #if(TonePWM_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (TonePWM_UseControl) */

    #endif /* (!TonePWM_UsingFixedFunction) */

}TonePWM_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    TonePWM_Start(void) ;
void    TonePWM_Stop(void) ;

#if (TonePWM_UseStatus || TonePWM_UsingFixedFunction)
    void  TonePWM_SetInterruptMode(uint8 interruptMode) ;
    uint8 TonePWM_ReadStatusRegister(void) ;
#endif /* (TonePWM_UseStatus || TonePWM_UsingFixedFunction) */

#define TonePWM_GetInterruptSource() TonePWM_ReadStatusRegister()

#if (TonePWM_UseControl)
    uint8 TonePWM_ReadControlRegister(void) ;
    void  TonePWM_WriteControlRegister(uint8 control)
          ;
#endif /* (TonePWM_UseControl) */

#if (TonePWM_UseOneCompareMode)
   #if (TonePWM_CompareMode1SW)
       void    TonePWM_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (TonePWM_CompareMode1SW) */
#else
    #if (TonePWM_CompareMode1SW)
        void    TonePWM_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (TonePWM_CompareMode1SW) */
    #if (TonePWM_CompareMode2SW)
        void    TonePWM_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (TonePWM_CompareMode2SW) */
#endif /* (TonePWM_UseOneCompareMode) */

#if (!TonePWM_UsingFixedFunction)
    uint8   TonePWM_ReadCounter(void) ;
    uint8 TonePWM_ReadCapture(void) ;

    #if (TonePWM_UseStatus)
            void TonePWM_ClearFIFO(void) ;
    #endif /* (TonePWM_UseStatus) */

    void    TonePWM_WriteCounter(uint8 counter)
            ;
#endif /* (!TonePWM_UsingFixedFunction) */

void    TonePWM_WritePeriod(uint8 period)
        ;
uint8 TonePWM_ReadPeriod(void) ;

#if (TonePWM_UseOneCompareMode)
    void    TonePWM_WriteCompare(uint8 compare)
            ;
    uint8 TonePWM_ReadCompare(void) ;
#else
    void    TonePWM_WriteCompare1(uint8 compare)
            ;
    uint8 TonePWM_ReadCompare1(void) ;
    void    TonePWM_WriteCompare2(uint8 compare)
            ;
    uint8 TonePWM_ReadCompare2(void) ;
#endif /* (TonePWM_UseOneCompareMode) */


#if (TonePWM_DeadBandUsed)
    void    TonePWM_WriteDeadTime(uint8 deadtime) ;
    uint8   TonePWM_ReadDeadTime(void) ;
#endif /* (TonePWM_DeadBandUsed) */

#if ( TonePWM_KillModeMinTime)
    void TonePWM_WriteKillTime(uint8 killtime) ;
    uint8 TonePWM_ReadKillTime(void) ;
#endif /* ( TonePWM_KillModeMinTime) */

void TonePWM_Init(void) ;
void TonePWM_Enable(void) ;
void TonePWM_Sleep(void) ;
void TonePWM_Wakeup(void) ;
void TonePWM_SaveConfig(void) ;
void TonePWM_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define TonePWM_INIT_PERIOD_VALUE          (255u)
#define TonePWM_INIT_COMPARE_VALUE1        (127u)
#define TonePWM_INIT_COMPARE_VALUE2        (63u)
#define TonePWM_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    TonePWM_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    TonePWM_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    TonePWM_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    TonePWM_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define TonePWM_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  TonePWM_CTRL_CMPMODE2_SHIFT)
#define TonePWM_DEFAULT_COMPARE1_MODE      (uint8)((uint8)1u <<  TonePWM_CTRL_CMPMODE1_SHIFT)
#define TonePWM_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (TonePWM_UsingFixedFunction)
   #define TonePWM_PERIOD_LSB              (*(reg16 *) TonePWM_PWMHW__PER0)
   #define TonePWM_PERIOD_LSB_PTR          ( (reg16 *) TonePWM_PWMHW__PER0)
   #define TonePWM_COMPARE1_LSB            (*(reg16 *) TonePWM_PWMHW__CNT_CMP0)
   #define TonePWM_COMPARE1_LSB_PTR        ( (reg16 *) TonePWM_PWMHW__CNT_CMP0)
   #define TonePWM_COMPARE2_LSB            (0x00u)
   #define TonePWM_COMPARE2_LSB_PTR        (0x00u)
   #define TonePWM_COUNTER_LSB             (*(reg16 *) TonePWM_PWMHW__CNT_CMP0)
   #define TonePWM_COUNTER_LSB_PTR         ( (reg16 *) TonePWM_PWMHW__CNT_CMP0)
   #define TonePWM_CAPTURE_LSB             (*(reg16 *) TonePWM_PWMHW__CAP0)
   #define TonePWM_CAPTURE_LSB_PTR         ( (reg16 *) TonePWM_PWMHW__CAP0)
   #define TonePWM_RT1                     (*(reg8 *)  TonePWM_PWMHW__RT1)
   #define TonePWM_RT1_PTR                 ( (reg8 *)  TonePWM_PWMHW__RT1)

#else
   #if (TonePWM_Resolution == 8u) /* 8bit - PWM */

       #if(TonePWM_PWMModeIsCenterAligned)
           #define TonePWM_PERIOD_LSB      (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define TonePWM_PERIOD_LSB_PTR  ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define TonePWM_PERIOD_LSB      (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define TonePWM_PERIOD_LSB_PTR  ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (TonePWM_PWMModeIsCenterAligned) */

       #define TonePWM_COMPARE1_LSB        (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define TonePWM_COMPARE1_LSB_PTR    ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define TonePWM_COMPARE2_LSB        (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define TonePWM_COMPARE2_LSB_PTR    ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define TonePWM_COUNTERCAP_LSB      (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define TonePWM_COUNTERCAP_LSB_PTR  ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define TonePWM_COUNTER_LSB         (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define TonePWM_COUNTER_LSB_PTR     ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define TonePWM_CAPTURE_LSB         (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define TonePWM_CAPTURE_LSB_PTR     ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(TonePWM_PWMModeIsCenterAligned)
               #define TonePWM_PERIOD_LSB      (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define TonePWM_PERIOD_LSB_PTR  ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define TonePWM_PERIOD_LSB      (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define TonePWM_PERIOD_LSB_PTR  ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (TonePWM_PWMModeIsCenterAligned) */

            #define TonePWM_COMPARE1_LSB       (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define TonePWM_COMPARE1_LSB_PTR   ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define TonePWM_COMPARE2_LSB       (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define TonePWM_COMPARE2_LSB_PTR   ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define TonePWM_COUNTERCAP_LSB     (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define TonePWM_COUNTERCAP_LSB_PTR ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define TonePWM_COUNTER_LSB        (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define TonePWM_COUNTER_LSB_PTR    ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define TonePWM_CAPTURE_LSB        (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define TonePWM_CAPTURE_LSB_PTR    ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(TonePWM_PWMModeIsCenterAligned)
               #define TonePWM_PERIOD_LSB      (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define TonePWM_PERIOD_LSB_PTR  ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define TonePWM_PERIOD_LSB      (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define TonePWM_PERIOD_LSB_PTR  ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (TonePWM_PWMModeIsCenterAligned) */

            #define TonePWM_COMPARE1_LSB       (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define TonePWM_COMPARE1_LSB_PTR   ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define TonePWM_COMPARE2_LSB       (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define TonePWM_COMPARE2_LSB_PTR   ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define TonePWM_COUNTERCAP_LSB     (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define TonePWM_COUNTERCAP_LSB_PTR ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define TonePWM_COUNTER_LSB        (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define TonePWM_COUNTER_LSB_PTR    ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define TonePWM_CAPTURE_LSB        (*(reg16 *) TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define TonePWM_CAPTURE_LSB_PTR    ((reg16 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define TonePWM_AUX_CONTROLDP1          (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define TonePWM_AUX_CONTROLDP1_PTR      ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (TonePWM_Resolution == 8) */

   #define TonePWM_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define TonePWM_AUX_CONTROLDP0          (*(reg8 *)  TonePWM_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define TonePWM_AUX_CONTROLDP0_PTR      ((reg8 *)   TonePWM_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (TonePWM_UsingFixedFunction) */

#if(TonePWM_KillModeMinTime )
    #define TonePWM_KILLMODEMINTIME        (*(reg8 *)  TonePWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define TonePWM_KILLMODEMINTIME_PTR    ((reg8 *)   TonePWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (TonePWM_KillModeMinTime ) */

#if(TonePWM_DeadBandMode == TonePWM__B_PWM__DBM_256_CLOCKS)
    #define TonePWM_DEADBAND_COUNT         (*(reg8 *)  TonePWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define TonePWM_DEADBAND_COUNT_PTR     ((reg8 *)   TonePWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define TonePWM_DEADBAND_LSB_PTR       ((reg8 *)   TonePWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define TonePWM_DEADBAND_LSB           (*(reg8 *)  TonePWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(TonePWM_DeadBandMode == TonePWM__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (TonePWM_UsingFixedFunction)
        #define TonePWM_DEADBAND_COUNT         (*(reg8 *)  TonePWM_PWMHW__CFG0)
        #define TonePWM_DEADBAND_COUNT_PTR     ((reg8 *)   TonePWM_PWMHW__CFG0)
        #define TonePWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << TonePWM_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define TonePWM_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define TonePWM_DEADBAND_COUNT         (*(reg8 *)  TonePWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define TonePWM_DEADBAND_COUNT_PTR     ((reg8 *)   TonePWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define TonePWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << TonePWM_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define TonePWM_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (TonePWM_UsingFixedFunction) */
#endif /* (TonePWM_DeadBandMode == TonePWM__B_PWM__DBM_256_CLOCKS) */



#if (TonePWM_UsingFixedFunction)
    #define TonePWM_STATUS                 (*(reg8 *) TonePWM_PWMHW__SR0)
    #define TonePWM_STATUS_PTR             ((reg8 *) TonePWM_PWMHW__SR0)
    #define TonePWM_STATUS_MASK            (*(reg8 *) TonePWM_PWMHW__SR0)
    #define TonePWM_STATUS_MASK_PTR        ((reg8 *) TonePWM_PWMHW__SR0)
    #define TonePWM_CONTROL                (*(reg8 *) TonePWM_PWMHW__CFG0)
    #define TonePWM_CONTROL_PTR            ((reg8 *) TonePWM_PWMHW__CFG0)
    #define TonePWM_CONTROL2               (*(reg8 *) TonePWM_PWMHW__CFG1)
    #define TonePWM_CONTROL3               (*(reg8 *) TonePWM_PWMHW__CFG2)
    #define TonePWM_GLOBAL_ENABLE          (*(reg8 *) TonePWM_PWMHW__PM_ACT_CFG)
    #define TonePWM_GLOBAL_ENABLE_PTR      ( (reg8 *) TonePWM_PWMHW__PM_ACT_CFG)
    #define TonePWM_GLOBAL_STBY_ENABLE     (*(reg8 *) TonePWM_PWMHW__PM_STBY_CFG)
    #define TonePWM_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) TonePWM_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define TonePWM_BLOCK_EN_MASK          (TonePWM_PWMHW__PM_ACT_MSK)
    #define TonePWM_BLOCK_STBY_EN_MASK     (TonePWM_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define TonePWM_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define TonePWM_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define TonePWM_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define TonePWM_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define TonePWM_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define TonePWM_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define TonePWM_CTRL_ENABLE            (uint8)((uint8)0x01u << TonePWM_CTRL_ENABLE_SHIFT)
    #define TonePWM_CTRL_RESET             (uint8)((uint8)0x01u << TonePWM_CTRL_RESET_SHIFT)
    #define TonePWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << TonePWM_CTRL_CMPMODE2_SHIFT)
    #define TonePWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << TonePWM_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define TonePWM_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define TonePWM_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << TonePWM_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define TonePWM_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define TonePWM_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define TonePWM_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define TonePWM_STATUS_TC_INT_EN_MASK_SHIFT            (TonePWM_STATUS_TC_SHIFT - 4u)
    #define TonePWM_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define TonePWM_STATUS_CMP1_INT_EN_MASK_SHIFT          (TonePWM_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define TonePWM_STATUS_TC              (uint8)((uint8)0x01u << TonePWM_STATUS_TC_SHIFT)
    #define TonePWM_STATUS_CMP1            (uint8)((uint8)0x01u << TonePWM_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define TonePWM_STATUS_TC_INT_EN_MASK              (uint8)((uint8)TonePWM_STATUS_TC >> 4u)
    #define TonePWM_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)TonePWM_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define TonePWM_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define TonePWM_RT1_MASK              (uint8)((uint8)0x03u << TonePWM_RT1_SHIFT)
    #define TonePWM_SYNC                  (uint8)((uint8)0x03u << TonePWM_RT1_SHIFT)
    #define TonePWM_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define TonePWM_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << TonePWM_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define TonePWM_SYNCDSI_EN            (uint8)((uint8)0x0Fu << TonePWM_SYNCDSI_SHIFT)


#else
    #define TonePWM_STATUS                (*(reg8 *)   TonePWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define TonePWM_STATUS_PTR            ((reg8 *)    TonePWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define TonePWM_STATUS_MASK           (*(reg8 *)   TonePWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define TonePWM_STATUS_MASK_PTR       ((reg8 *)    TonePWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define TonePWM_STATUS_AUX_CTRL       (*(reg8 *)   TonePWM_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define TonePWM_CONTROL               (*(reg8 *)   TonePWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define TonePWM_CONTROL_PTR           ((reg8 *)    TonePWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define TonePWM_CTRL_ENABLE_SHIFT      (0x07u)
    #define TonePWM_CTRL_RESET_SHIFT       (0x06u)
    #define TonePWM_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define TonePWM_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define TonePWM_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define TonePWM_CTRL_ENABLE            (uint8)((uint8)0x01u << TonePWM_CTRL_ENABLE_SHIFT)
    #define TonePWM_CTRL_RESET             (uint8)((uint8)0x01u << TonePWM_CTRL_RESET_SHIFT)
    #define TonePWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << TonePWM_CTRL_CMPMODE2_SHIFT)
    #define TonePWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << TonePWM_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define TonePWM_STATUS_KILL_SHIFT          (0x05u)
    #define TonePWM_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define TonePWM_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define TonePWM_STATUS_TC_SHIFT            (0x02u)
    #define TonePWM_STATUS_CMP2_SHIFT          (0x01u)
    #define TonePWM_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define TonePWM_STATUS_KILL_INT_EN_MASK_SHIFT          (TonePWM_STATUS_KILL_SHIFT)
    #define TonePWM_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (TonePWM_STATUS_FIFONEMPTY_SHIFT)
    #define TonePWM_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (TonePWM_STATUS_FIFOFULL_SHIFT)
    #define TonePWM_STATUS_TC_INT_EN_MASK_SHIFT            (TonePWM_STATUS_TC_SHIFT)
    #define TonePWM_STATUS_CMP2_INT_EN_MASK_SHIFT          (TonePWM_STATUS_CMP2_SHIFT)
    #define TonePWM_STATUS_CMP1_INT_EN_MASK_SHIFT          (TonePWM_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define TonePWM_STATUS_KILL            (uint8)((uint8)0x00u << TonePWM_STATUS_KILL_SHIFT )
    #define TonePWM_STATUS_FIFOFULL        (uint8)((uint8)0x01u << TonePWM_STATUS_FIFOFULL_SHIFT)
    #define TonePWM_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << TonePWM_STATUS_FIFONEMPTY_SHIFT)
    #define TonePWM_STATUS_TC              (uint8)((uint8)0x01u << TonePWM_STATUS_TC_SHIFT)
    #define TonePWM_STATUS_CMP2            (uint8)((uint8)0x01u << TonePWM_STATUS_CMP2_SHIFT)
    #define TonePWM_STATUS_CMP1            (uint8)((uint8)0x01u << TonePWM_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define TonePWM_STATUS_KILL_INT_EN_MASK            (TonePWM_STATUS_KILL)
    #define TonePWM_STATUS_FIFOFULL_INT_EN_MASK        (TonePWM_STATUS_FIFOFULL)
    #define TonePWM_STATUS_FIFONEMPTY_INT_EN_MASK      (TonePWM_STATUS_FIFONEMPTY)
    #define TonePWM_STATUS_TC_INT_EN_MASK              (TonePWM_STATUS_TC)
    #define TonePWM_STATUS_CMP2_INT_EN_MASK            (TonePWM_STATUS_CMP2)
    #define TonePWM_STATUS_CMP1_INT_EN_MASK            (TonePWM_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define TonePWM_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define TonePWM_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define TonePWM_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define TonePWM_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define TonePWM_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* TonePWM_UsingFixedFunction */

#endif  /* CY_PWM_TonePWM_H */


/* [] END OF FILE */
