/*******************************************************************************
* File Name: ToneQD.h  
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the Quadrature
*  Decoder component.
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_QUADRATURE_DECODER_ToneQD_H)
#define CY_QUADRATURE_DECODER_ToneQD_H

#include "cyfitter.h"
#include "CyLib.h"
#include "cytypes.h"

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component QuadDec_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#define ToneQD_COUNTER_SIZE               (8u)
#define ToneQD_COUNTER_SIZE_8_BIT         (8u)
#define ToneQD_COUNTER_SIZE_16_BIT        (16u)
#define ToneQD_COUNTER_SIZE_32_BIT        (32u)

#if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT)
    #include "ToneQD_Cnt8.h"
#else 
    /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_16_BIT) || 
    *  (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT) 
    */
    #include "ToneQD_Cnt16.h"
#endif /* ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT */

extern uint8 ToneQD_initVar;


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define ToneQD_COUNTER_RESOLUTION         (4u)


/***************************************
*       Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
} ToneQD_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  ToneQD_Init(void) ;
void  ToneQD_Start(void) ;
void  ToneQD_Stop(void) ;
void  ToneQD_Enable(void) ;
uint8 ToneQD_GetEvents(void) ;
void  ToneQD_SetInterruptMask(uint8 mask) ;
uint8 ToneQD_GetInterruptMask(void) ;
int8 ToneQD_GetCounter(void) ;
void  ToneQD_SetCounter(int8 value)
;
void  ToneQD_Sleep(void) ;
void  ToneQD_Wakeup(void) ;
void  ToneQD_SaveConfig(void) ;
void  ToneQD_RestoreConfig(void) ;

#if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT)
    CY_ISR_PROTO(ToneQD_ISR);
#endif /* ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT */


/***************************************
*           API Constants
***************************************/

#if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT)
    #define ToneQD_ISR_NUMBER             ((uint8) ToneQD_isr__INTC_NUMBER)
    #define ToneQD_ISR_PRIORITY           ((uint8) ToneQD_isr__INTC_PRIOR_NUM)
#endif /* ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT */


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define ToneQD_GLITCH_FILTERING           (0u)
#define ToneQD_INDEX_INPUT                (0u)


/***************************************
*    Initial Parameter Constants
***************************************/

#if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT)
    #define ToneQD_COUNTER_INIT_VALUE    (0x80u)
#else 
    /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_16_BIT) ||
    *  (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT)
    */
    #define ToneQD_COUNTER_INIT_VALUE    (0x8000u)
    #define ToneQD_COUNTER_MAX_VALUE     (0x7FFFu)
#endif /* ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT */


/***************************************
*             Registers
***************************************/

#define ToneQD_STATUS_REG                 (* (reg8 *) ToneQD_bQuadDec_Stsreg__STATUS_REG)
#define ToneQD_STATUS_PTR                 (  (reg8 *) ToneQD_bQuadDec_Stsreg__STATUS_REG)
#define ToneQD_STATUS_MASK                (* (reg8 *) ToneQD_bQuadDec_Stsreg__MASK_REG)
#define ToneQD_STATUS_MASK_PTR            (  (reg8 *) ToneQD_bQuadDec_Stsreg__MASK_REG)
#define ToneQD_SR_AUX_CONTROL             (* (reg8 *) ToneQD_bQuadDec_Stsreg__STATUS_AUX_CTL_REG)
#define ToneQD_SR_AUX_CONTROL_PTR         (  (reg8 *) ToneQD_bQuadDec_Stsreg__STATUS_AUX_CTL_REG)


/***************************************
*        Register Constants
***************************************/

#define ToneQD_COUNTER_OVERFLOW_SHIFT     (0x00u)
#define ToneQD_COUNTER_UNDERFLOW_SHIFT    (0x01u)
#define ToneQD_COUNTER_RESET_SHIFT        (0x02u)
#define ToneQD_INVALID_IN_SHIFT           (0x03u)
#define ToneQD_COUNTER_OVERFLOW           ((uint8) (0x01u << ToneQD_COUNTER_OVERFLOW_SHIFT))
#define ToneQD_COUNTER_UNDERFLOW          ((uint8) (0x01u << ToneQD_COUNTER_UNDERFLOW_SHIFT))
#define ToneQD_COUNTER_RESET              ((uint8) (0x01u << ToneQD_COUNTER_RESET_SHIFT))
#define ToneQD_INVALID_IN                 ((uint8) (0x01u << ToneQD_INVALID_IN_SHIFT))

#define ToneQD_INTERRUPTS_ENABLE_SHIFT    (0x04u)
#define ToneQD_INTERRUPTS_ENABLE          ((uint8)(0x01u << ToneQD_INTERRUPTS_ENABLE_SHIFT))
#define ToneQD_INIT_INT_MASK              (0x0Fu)


/******************************************************************************************
* Following code are OBSOLETE and must not be used starting from Quadrature Decoder 2.20
******************************************************************************************/
#define ToneQD_DISABLE                    (0x00u)


#endif /* CY_QUADRATURE_DECODER_ToneQD_H */


/* [] END OF FILE */
