/*******************************************************************************
* File Name: ToneQD_PM.c
* Version 3.0
*
* Description:
*  This file contains the setup, control and status commands to support 
*  component operations in low power mode.  
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ToneQD.h"

static ToneQD_BACKUP_STRUCT ToneQD_backup = {0u};


/*******************************************************************************
* Function Name: ToneQD_SaveConfig
********************************************************************************
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ToneQD_SaveConfig(void) 
{
    #if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT)
        ToneQD_Cnt8_SaveConfig();
    #else 
        /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_16_BIT) || 
         * (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT)
         */
        ToneQD_Cnt16_SaveConfig();
    #endif /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: ToneQD_RestoreConfig
********************************************************************************
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ToneQD_RestoreConfig(void) 
{
    #if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT)
        ToneQD_Cnt8_RestoreConfig();
    #else 
        /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_16_BIT) || 
         * (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT) 
         */
        ToneQD_Cnt16_RestoreConfig();
    #endif /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: ToneQD_Sleep
********************************************************************************
* 
* Summary:
*  Prepare Quadrature Decoder Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ToneQD_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ToneQD_Sleep(void) 
{
    if (0u != (ToneQD_SR_AUX_CONTROL & ToneQD_INTERRUPTS_ENABLE))
    {
        ToneQD_backup.enableState = 1u;
    }
    else /* The Quadrature Decoder Component is disabled */
    {
        ToneQD_backup.enableState = 0u;
    }

    ToneQD_Stop();
    ToneQD_SaveConfig();
}


/*******************************************************************************
* Function Name: ToneQD_Wakeup
********************************************************************************
*
* Summary:
*  Prepare Quadrature Decoder Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ToneQD_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void ToneQD_Wakeup(void) 
{
    ToneQD_RestoreConfig();

    if (ToneQD_backup.enableState != 0u)
    {
        #if (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT)
            ToneQD_Cnt8_Enable();
        #else 
            /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_16_BIT) || 
            *  (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_32_BIT) 
            */
            ToneQD_Cnt16_Enable();
        #endif /* (ToneQD_COUNTER_SIZE == ToneQD_COUNTER_SIZE_8_BIT) */

        /* Enable component's operation */
        ToneQD_Enable();
    } /* Do nothing if component's block was disabled before */
}


/* [] END OF FILE */

