/*******************************************************************************
* File: QEX Challenge
* 
* Version : 2.9a    
*
* Description: Morse-code keyer function
* Jon Titus KZ1G, Herriman, UT 84096  Date: 06-29-2019 at 0918H MDT
*
*Copyright 2019, Jonathan A. Titus

Permission is hereby granted, free of charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.  Please acknowledge the source and author.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
*
*******************************************************************************/
#include <device.h>
#include <stdio.h>
#include <CyLib.h>
#define SHIFT 0x02              //Bit in USB status byte for a shifted keyboard character

uint8  charindex = 64;          //Accumulate value to point to character in array
uint8  counter = 32;            //Start array index with a value of 64--midpoint
uint8  dotPeriod;               //Standard period for a Morse dot
uint16 dashPeriod;              
uint16 Count_2X;
uint16 Count_6X;
unsigned char keyFlag;

uint8 CodeQD_Memory = 0;        //EEPROM addresses for configuration bytes to save
uint8 ToneQD_Memory = 1;
uint8 TonePeriod_Memory = 2;

uint8 TonePeriod;               //More variables used to get tone and code-speed info              
uint8 ToneCompare;
uint8 ToneQDflags;
uint8 CodeQDflags;
uint8 CodeSpeed;

void  In_EP (void);             //USB function prototypes
void  Out_EP (void);

//External variable where USB OUT Report. From Cypress

extern uint8 USBFS_1_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_OUT_BUF[USBFS_1_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_OUT_BUF_SIZE];

//Creates a look-up array for Morse code to USB keyboard codes (NOT ASCII!)
//0xC0 added to symbols that require a shift.  Just for ID purposes. It gets subtracted later.

const uint8 Morse_to_USB[] =
{0x00, 0x00, 0x27, 0x00, 0x00, 0x00, 0x26, 0x00, 0x12, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0xf3, 
0x10, 0x00, 0x00, 0x00, 0x14, 0x00, 0x00, 0x00, 0x0a, 0x36, 0x00, 0x00, 0x1d, 0x00, 0x24, 0x00,
0x17, 0x00, 0x00, 0x00, 0x1c, 0xe7, 0xe6, 0x00, 0x0e, 0xde, 0x00, 0x33, 0x06, 0x00, 0x00, 0x00,
0x11, 0x00, 0x00, 0x00, 0x1b, 0x00, 0x38, 0x00, 0x07, 0x00, 0x2e, 0x00, 0x05, 0x2d, 0x23, 0x00,
0x00, 0x00, 0x1e, 0x34, 0x0d, 0x00, 0x00, 0x00, 0x1a, 0x00, 0x00, 0xdf, 0x13, 0x00, 0x00, 0x00,
0x04, 0x00, 0x00, 0x00, 0x28, 0x37, 0xee, 0x00, 0x15, 0x00, 0x00, 0xf4, 0x0f, 0x00, 0xe4, 0x00,
0x08, 0x00, 0x1f, 0x00, 0x00, 0xed, 0x00, 0xf8, 0x18, 0x00, 0x00, 0x00, 0x09, 0x00, 0x00, 0x00,
0x0c, 0x00, 0x20, 0x00, 0x19, 0x00, 0x00, 0x00, 0x16, 0x00, 0x21, 0x00, 0x0b, 0x00, 0x22, 0x00};
								   
static unsigned char Keyboard_Data[8] = {0, 0, 0, 0, 0, 0, 0, 0}; //Buffer for USB message to PC
static unsigned char Out_Data[1] = {0};                           //Buffer for USB message from PC (flags)
static uint8 key;                                                 //USB key-scan code to sent to PC

// ******************* ISR for 2X timer--space between dots & dashes *******************

CY_ISR( Timer_2X_Handler )              //Interrupt fires if next dot or dash not quick enough
{   
    Timer_2X_ReadControlRegister();     //Read solely to clear interrupt flag
    keyFlag = 1;                        //set keyFlag to signal end of character   
}

// ******************* ISR for 6X timer--space between words *******************
CY_ISR( Timer_6X_Handler )              //Interrupt fires if we need a space between characters
{
    Timer_6X_ReadControlRegister();     //Read solely to clear interrupt flag
    keyFlag = 2;                        //Set flag to so In_EP sends a "space" code to the PC.
    charindex = 64;                     //Reset starting value for array index to character
    counter = 32;                       //Reset bit added or subtracted to get array indexd
}

// ******************* Function to send data to PC via USB *******************

void In_EP()                                    //Function to send keyboard information to PC via USB
{	
    if (( keyFlag == 1) || (keyFlag == 2))      //Test key flags, proceed if either one set
    {
        if (keyFlag == 1)                       //End of character flag
        {
            key = Morse_to_USB[charindex];      //Get character code and send to USB
    
            //Test for characters that need a shift bit sent: ? _ & @ ! ) ( and :
            if(key >0xd0)                       //Set Shift bit for chars with codes above this value
			{
				Keyboard_Data[0] = SHIFT;       //Set proper bit in USB buffer for a shifted character
                key = key - 0xc0;               //Subtract 0xC0 to get character code for shifted chars
            }
 			else                                //Don't need to shift for a character
			{	
			    Keyboard_Data[0] = 0x00;        //No Shift bit in USB buffer, just 0x00
			}
            charindex = 64;                     //OK, got key data, clear these vars for next Morse character
            counter = 32;
        }
        if (keyFlag == 2)                               //Test end-of-word flag
        {
            key = 0x2c;                                 //Found it. Set key for 0x2C, or "space"
        }
            Keyboard_Data[2] = key;                     //Put key code in data-to-PC buffer         
            USBFS_1_LoadInEP(1, Keyboard_Data, 8);      //Loads Endpoint 1 for transfer IN to PC				
            while(!USBFS_1_bGetEPAckState(1));          //Waits for PC to acknowledge				
			Keyboard_Data[0] = 0x00;                    //Resets flag bits					
			Keyboard_Data[2] = 0x00;                    //Resets keycode
			USBFS_1_LoadInEP(1, Keyboard_Data, 8);		//Load data going to PC			
			while(!USBFS_1_bGetEPAckState(1))           //Waits for PC to acknowledge
            {};
            keyFlag = 0;                                //Reset keyFlag value
    }
}

// ******************* Function to get data from PC via USB *******************

void Out_EP (void)      //Gets data for Caps-Lock and Num_Lock LEDs and controls them.
{	
	Out_Data[0] = USBFS_1_DEVICE0_CONFIGURATION0_INTERFACE0_ALTERNATE0_HID_OUT_BUF[0];  //Get USB data from PC
    Out_Data[0] = Out_Data[0] & 0x03;       //Mask unneeded bits   
	switch(Out_Data[0])                     //Choose LEDs to turn on or off
    {
        case 0:                             //Neither Caps_Lock nor Num_Lock set
        Num_Lock_Write(0);
        Caps_Lock_Write(0);
        break;
        
        case 1:                             //Num_Lock set, turn on its LED
        Num_Lock_Write(1);
        break;
        
        case 2:                             //Caps_Lock set, turn on its LED
        Caps_Lock_Write(1);
        break;
        
        case 3:                             //Caps_Lock and Num_Lock set, turn on both LEDs
        Num_Lock_Write(1);
        Caps_Lock_Write(1);
    }
    Keyboard_Data[2] = 0x00;                //Clear flag data going to PC
    USBFS_1_LoadInEP(1, Keyboard_Data, 8);  //Load data into message buffes to PC
}

// ******************* Function to let user update code-speed and tone data USB *******************
// ******************* and save data to EEPROM if they choose to                *******************

void adjustToneSpeed(void)
{            
    EEPROM_FF_Reset_Write(1);                   //Put logic-1 on EEPROM flip-flop Reset
    CyDelay(5);                                 //Stretch pulse to 5 millisec.
    EEPROM_FF_Reset_Write(0);                   //Put logic-0 on flip flop, OK to run
            
    TonePeriod = ToneQD_GetCounter() + 128;     //Refrest tone settings add 128 offset                     
    ToneCompare = TonePeriod / 2;               //Half tone periof for square wave               
    ToneQDflags = ToneQD_GetEvents();           //Get flags from CodeQD to test
    TonePWM_WritePeriod(TonePeriod);            //  for values 0 to 255                
    TonePWM_WriteCompare(ToneCompare);
                       
    if ((ToneQDflags & 0x01) == 0x01)           //overflow. Reset counter to a slightly 
    {                                           //smaller value than 128
        ToneQD_SetCounter(112);     
    }
    if ((ToneQDflags & 0x02) == 0x02)           //underflow.  Reset counter to a value                                          //              
    {                                           //slightly above -127
        ToneQD_SetCounter(0x8C);               
    }    
               
    dotPeriod = CodeQD_GetCounter() + 128;      //Add 128 to QD output for 0-255 value
    dashPeriod = dotPeriod * 3;                 //Re-calculate dash period to start with
    Count_2X = dotPeriod * 2;                   //Re-calculate 2X period
    Count_6X = dotPeriod * 6;                   //Re-calculate 6X periodLED_Register_Write(CodeSpeed);
    CodeQDflags = CodeQD_GetEvents();           //Get flags from CodeQD to test for
    if ((CodeQDflags & 0x01) == 0x01)           //overflow. Reset counter to a slightly 
    {                                           //smaller value than 128
        CodeQD_SetCounter(112);     
    }
    if ((CodeQDflags & 0x02) == 0x02)           //underflow.  Reset counter to a value                                           //              
    {                                           //slightly above -127
        CodeQD_SetCounter(0x8C);               
    }
               
    if (Save_EEPROM_Read() == 0x01)               //If flag detected
    {
        EEPROM_1_WriteByte(CodeQD_GetCounter(), CodeQD_Memory); //Save QD counts in EEPROM
        EEPROM_1_WriteByte(ToneQD_GetCounter(), ToneQD_Memory);
        EEPROM_1_WriteByte(TonePeriod, TonePeriod_Memory);      //Save PWM period in EEPROM
        
        for (int i = 0; i < 3; i++)                //Completed EEPROM write, so flash LED 3 times
        {
            EEPROM_Write_Write(1);                           
            CyDelay(100);
            EEPROM_Write_Write(0);
            CyDelay(100);
        }
        EEPROM_FF_Reset_Write(1);                   //Pulse to clear EEPROM_FF flag after EEPROM write
        CyDelay(5);                                 //Stretch reset to 5 msec.
        EEPROM_FF_Reset_Write(0);       
    }
    return;
}

// ******************* Main Program *******************

int main()
{
    //Start and assign interrupt handles for PSoC interrupting Timers
	CyGlobalIntEnable;                                      //Enable system interrupts
    EEPROM_1_Start();                                       //Start EEPROM_1 operation
    EEPROM_1_UpdateTemperature();                           //Update chip temp value
    EEPROM_FF_Reset_Write(1);                               //Reset the EEPROM_FF flag
    EEPROM_FF_Reset_Write(0);
    
    CodeQD_Start();                                         //Start Code quad decoder
    CodeQD_SetCounter(EEPROM_1_ReadByte(CodeQD_Memory));    //Load it with last saved EEPROM value
    dotPeriod = EEPROM_1_ReadByte(CodeQD_Memory);           //Use this value to set Morse rate
    dashPeriod = dotPeriod * 3;                             //Calculate dash period to start with
    Count_2X = dotPeriod * 2;                               //Calculate 2X period
    Count_6X = dotPeriod * 6;                               //Calculate 6X period
    
    ToneQD_Start();                                         //Start Tone quad decoder
    ToneQD_SetCounter(EEPROM_1_ReadByte(ToneQD_Memory));    //Load it with last saved EEPROM value
    
    TonePWM_Start();                                        //Start Tone PWM for tone output
    TonePeriod = EEPROM_1_ReadByte(TonePeriod_Memory);      //Get the last saved tone Period value
    ToneCompare = TonePeriod / 2;                           //Square wave, so half on, half off
    TonePWM_WritePeriod(TonePeriod);                        //Set the tone period
    TonePWM_WriteCompare(ToneCompare);                      //Set compare for half the period
       
    USBFS_1_Start(0, USBFS_1_DWR_VDDD_OPERATION);           //Start USBFS Operation for Device 0 and 5V
	USBFS_1_EnableOutEP(2);                                 //Enables OUT EP -- message from PC	
    while(!USBFS_1_bGetConfiguration());                    //Begins USB Traffic
	
    USBFS_1_LoadInEP(1, Keyboard_Data, 8);    	
    
    Timer_2X_ReadControlRegister();                 //Clear any lingering interrupts
    Timer_6X_ReadControlRegister();
    Timer_2X_int_StartEx(Timer_2X_Handler);         //Interrupt handler addresses
    Timer_6X_int_StartEx(Timer_6X_Handler);
    
    dashPeriod = dotPeriod * 3;                     //Calculate dash period
    Count_2X = dotPeriod * 2;                       //Calculate 2X period
    Count_6X = dotPeriod * 6;
    
// ******************* The PSoC MCU spends most of its time in this for(;;) loop *******************

    for(;;)                                         //Morse-code software starts here
    {       
        if(USBFS_1_bGetEPAckState(1))               //Checks for ACK from USB host
		{			
			In_EP(); 	                            //Function to Send Data to PC				
			Out_EP();                               //Function to receive data from PC
		}
        if(Config_Switch_Status_Read() == 1)        //Test the state of the RUN/CONFIG switch
        {
            adjustToneSpeed();                      //If CONFIG, run this function
        }
        
        Timer_2X_WritePeriod(Count_2X);             //Update the timers
        Timer_6X_WritePeriod(Count_6X);

        if(DotIn_Read() == 0)                   //Test for a DOT (logic-0) at the key
        {
           Timers_RST_Write(1);                 //Reset both timers, Logic-1 pulse
           CyDelay(2);                          //Delay for clock edge to reset
           Timers_RST_Write(0);                 //Back to logic-0
           Indicator_Write(1);                  //Turn on LED & sidetone for a dot
           CyDelay(dotPeriod);                  //Wait dotPeriod for a dot
           charindex = charindex + counter;     //Add counter to identify Morse character
           counter = counter/2;                 //divide counter by 2Timers_RST_Write(1);
           Indicator_Write(0);                  //Turn off LED / sidetone                         
           Timer_2X_Start();                    //Start both timers
           Timer_6X_Start();
           Timers_TRIG_Write(1);                //Trigger both timers
           CyDelay(2);
           Timers_TRIG_Write(0);                //Clear trigge          
           CyDelay(dotPeriod);                  //Wait for a dot period
        }
        
        if(DashIn_Read() == 0)                  //Test for a DASH (logic-0) at the key
        {   
           Timers_RST_Write(1);                 //Reset both timers
           CyDelay(2);
           Timers_RST_Write(0);                 //Clear reset
           Indicator_Write(1);                  //Turn on LED & sidetone for a dash
           CyDelay(dashPeriod);                 //Wait 3-times a dotPeriod for a dash
           charindex = charindex - counter;     //Subtract counter to identify Morse character
           counter = counter/2;                 //divide counter by 2
           Indicator_Write(0);                  //Turn off LED / sidetone          
           Timer_2X_Start();
           Timer_6X_Start();          
           Timers_TRIG_Write(1);                //Trigger both timers
           CyDelay(2);
           Timers_TRIG_Write(0);                //Clear trigger         
           CyDelay(dotPeriod);                  //Wait for a dotPeriod
        }
    }
}
// ******************* End of Program File ********************
